# Obelisk Python Client

![version](https://img.shields.io/pypi/v/obelisk-py)
![build-docs](https://img.shields.io/github/workflow/status/predict-idlab/obelisk-python/pages%20build%20and%20deployment?label=docs)

## Installation

```
pip install obelisk-py
```

## Documentation

[Read the docs](https://predict-idlab.github.io/obelisk-python/)